import { AbstractCoreComponent } from "./AbstractCoreComponent";
import { RoutedCoreComponentModel } from "./model/RoutedCoreComponentModel";
/**
 * AbstractRoutedCoreComponent
 * This core component contains 1 or more links.
 * We want to be able to control SPA routing with a property coming from the model.
 */
export declare abstract class AbstractRoutedCoreComponent extends AbstractCoreComponent implements RoutedCoreComponentModel {
    /**
     * Flag the entire core component to have routed links
     */
    routed: any;
    /**
     * Determine if an individual item (such as navigation entry or list link) should be routed or not.
     *
     * item: the entry item in a component, think of a link that belongs to a collection of links in the navigation.
     *       we can specify here to disable routing, or to overrule routing of the base component
     * base component: the component itself, think of the navigation itself.
     *       we can specify the default behaviour of all items here.
     *
     * The following scenarios result in routing:
     * Scenario 1: The item or the base component don't have anything set, we assume true (except for external links starting with http)
     * Scenario 2: The base component has routing on false, but the item has it on true (item takes precedence)
     * Scenario 3: The base component or item, or both, have the routing values set to true.
     *
     * The following scenario does NOT result in routing:
     * Scenario 1: The base component has routing enabled, but the item has it set to false
     * @param item
     */
    isItemRouted(item: RoutedCoreComponentModel): boolean;
}
