import { __decorate, __metadata } from 'tslib';
import { Input, Component, NgModule } from '@angular/core';
import { NavigationV1Component, AemAngularCoreWcmComponentsNavigationV1 } from '@adobe/aem-core-components-angular-base/layout/navigation/v1';
import { NavigationV1IsEmptyFn, AemAngularCoreWcmComponentsCore } from '@adobe/aem-core-components-angular-base/core';
import { CommonModule } from '@angular/common';
import { BrowserModule } from '@angular/platform-browser';
import { RouterModule } from '@angular/router';

/*
 *  Copyright 2020 Adobe
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
let LanguageNavigationV1Component = class LanguageNavigationV1Component extends NavigationV1Component {
    constructor() {
        super(...arguments);
        this.baseCssClass = 'cmp-languagenavigation';
    }
    get isEmpty() {
        return NavigationV1IsEmptyFn(this);
    }
    getItemCssClass(item) {
        const parent = super.getItemCssClass(item);
        const countryCode = ` ${this.baseCssClass}__item--countrycode-${item.country}`;
        const langCode = ` ${this.baseCssClass}__item--langcode-${item.language}`;
        return parent + countryCode + langCode;
    }
    /**
     * You may overrule this method to determine for example based on current URL / page context whether the item is active.
     * @param item
     */
    isItemActive(item) {
        return item.active;
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], LanguageNavigationV1Component.prototype, "baseCssClass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], LanguageNavigationV1Component.prototype, "items", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], LanguageNavigationV1Component.prototype, "accessibilityLabel", void 0);
LanguageNavigationV1Component = __decorate([
    Component({
        selector: 'core-language-navigation-v1',
        template: "<!--/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n  ~ Copyright 2020 Adobe\n  ~\n  ~ Licensed under the Apache License, Version 2.0 (the \"License\");\n  ~ you may not use this file except in compliance with the License.\n  ~ You may obtain a copy of the License at\n  ~\n  ~     http://www.apache.org/licenses/LICENSE-2.0\n  ~\n  ~ Unless required by applicable law or agreed to in writing, software\n  ~ distributed under the License is distributed on an \"AS IS\" BASIS,\n  ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n  ~ See the License for the specific language governing permissions and\n  ~ limitations under the License.\n  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/-->\n\n<div *ngIf=\"isEmpty; then placeHolderBlock else componentBlock\"></div>\n\n<ng-template #placeHolderBlock>\n    <core-placeholder *ngIf=\"shouldShowPlaceHolder\" componentTitle=\"LanguageNavigationV1\"></core-placeholder>\n</ng-template>\n\n<ng-template #componentBlock>\n    \n    <nav\n         id=\"{{id}}\"\n         class=\"{{baseCssClass}}\"\n         role=\"navigation\"\n         itemScope itemType=\"http://schema.org/SiteNavigationElement\"\n         [attr.data-cmp-data-layer]=\"dataLayerString\"\n         [attr.aria-label]=\"accessibilityLabel\">\n        <ul class=\"{{baseCssClass}}__group\">\n            <ng-container *ngFor=\"let childItem of items; let i = index\">\n                <ng-container [ngTemplateOutlet]=\"navigationItem\" [ngTemplateOutletContext]=\"{item:childItem}\"></ng-container>\n            </ng-container>\n        </ul>\n    </nav>\n\n</ng-template>\n\n<ng-template #navigationGroup let-item='item'>\n    <ul class=\"{{baseCssClass}}__group\">\n        <ng-container *ngFor=\"let childItem of item.children; let i = index\">\n            <ng-container [ngTemplateOutlet]=\"navigationItem\" [ngTemplateOutletContext]=\"{item:childItem}\"></ng-container>\n        </ng-container>\n    </ul>\n</ng-template>\n\n\n<ng-template #navigationItem let-item='item'>\n    <li [ngClass]=\"getItemCssClass(item)\">\n        <ng-container *ngIf=\"item.level===0\">\n            <ng-container [ngTemplateOutlet]=\"navigationSpan\" [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n        </ng-container>\n        <ng-container *ngIf=\"item.level!==0\">\n            <ng-container [ngTemplateOutlet]=\"navigationLink\" [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n        </ng-container>\n        <ng-container *ngIf=\"!!item.children && item.children.length > 0\" [ngTemplateOutlet]=\"navigationGroup\"\n                      [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n    </li>\n</ng-template>\n\n<ng-template #navigationSpan let-item='item'>\n    <span class=\"{{baseCssClass}}__item-title\" lang=\"{{item.language}}\">{{item.title}}</span>\n</ng-template>\n\n<ng-template #navigationLink let-item='item'>\n    <a class=\"{{baseCssClass}}__item-link\"\n       title=\"{{item.title}}\"\n       href=\"{{item.url}}\"\n       lang=\"{{item.language}}\"\n       rel=\"alternate\"\n       [attr.hrefLang]=\"item.language\"\n       [attr.aria-current]=\"item.active\">\n        {{item.title}}\n    </a>\n</ng-template>"
    })
], LanguageNavigationV1Component);

let AemAngularCoreWcmComponentsLanguageNavigationV1 = class AemAngularCoreWcmComponentsLanguageNavigationV1 {
};
AemAngularCoreWcmComponentsLanguageNavigationV1 = __decorate([
    NgModule({
        imports: [CommonModule, BrowserModule, RouterModule, AemAngularCoreWcmComponentsCore, AemAngularCoreWcmComponentsNavigationV1],
        declarations: [
            LanguageNavigationV1Component
        ],
        exports: [
            LanguageNavigationV1Component
        ],
        entryComponents: [
            LanguageNavigationV1Component,
        ],
    })
], AemAngularCoreWcmComponentsLanguageNavigationV1);

/**
 * Generated bundle index. Do not edit.
 */

export { AemAngularCoreWcmComponentsLanguageNavigationV1, LanguageNavigationV1Component };
//# sourceMappingURL=adobe-aem-core-components-angular-base-layout-language-navigation-v1.js.map
