import { __decorate, __metadata, __param } from 'tslib';
import { Inject, Input, Component, NgModule } from '@angular/core';
import { AbstractRoutedCoreComponent, NavigationV1IsEmptyFn, NAVIGATION_UTIL_SERVICE, AemAngularCoreWcmComponentsCore } from '@adobe/aem-core-components-angular-base/core';
export { NavigationV1IsEmptyFn } from '@adobe/aem-core-components-angular-base/core';
import { CommonModule } from '@angular/common';
import { BrowserModule } from '@angular/platform-browser';
import { RouterModule } from '@angular/router';

/*
 *  Copyright 2020 Adobe
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
let NavigationV1Component = class NavigationV1Component extends AbstractRoutedCoreComponent {
    constructor(navigationUtilService) {
        super();
        this.baseCssClass = 'cmp-navigation';
        this.navigationUtilService = navigationUtilService;
    }
    get isEmpty() {
        return NavigationV1IsEmptyFn(this);
    }
    getItemCssClass(item) {
        const active = this.isItemActive(item) ? ` ${this.baseCssClass}__item--active` : '';
        const level = ` ${this.baseCssClass}__item--level-${item.level}`;
        return `${this.baseCssClass}__item${active}${level}`;
    }
    /**
     * You may overrule this method to determine for example based on current URL / page context whether the item is active.
     * @param item
     */
    isItemActive(item) {
        return this.navigationUtilService.isItemActive(item);
    }
};
NavigationV1Component.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [NAVIGATION_UTIL_SERVICE,] }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], NavigationV1Component.prototype, "baseCssClass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], NavigationV1Component.prototype, "items", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], NavigationV1Component.prototype, "accessibilityLabel", void 0);
NavigationV1Component = __decorate([
    Component({
        selector: 'core-navigation-v1',
        template: "<!--/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n  ~ Copyright 2020 Adobe\n  ~\n  ~ Licensed under the Apache License, Version 2.0 (the \"License\");\n  ~ you may not use this file except in compliance with the License.\n  ~ You may obtain a copy of the License at\n  ~\n  ~     http://www.apache.org/licenses/LICENSE-2.0\n  ~\n  ~ Unless required by applicable law or agreed to in writing, software\n  ~ distributed under the License is distributed on an \"AS IS\" BASIS,\n  ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n  ~ See the License for the specific language governing permissions and\n  ~ limitations under the License.\n  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/-->\n\n<div *ngIf=\"isEmpty; then placeHolderBlock else componentBlock\"></div>\n\n<ng-template #placeHolderBlock>\n    <core-placeholder *ngIf=\"shouldShowPlaceHolder\" componentTitle=\"NavigationV1\"></core-placeholder>\n</ng-template>\n\n<ng-template #componentBlock>\n    \n    <nav id=\"{{id}}\"\n         class=\"{{baseCssClass}}\"\n         role=\"navigation\"\n         itemScope itemType=\"http://schema.org/SiteNavigationElement\"\n         [attr.data-cmp-data-layer]=\"dataLayerString\"\n         [attr.aria-label]=\"accessibilityLabel\">\n        <ul class=\"{{baseCssClass}}__group\">\n            <ng-container *ngFor=\"let childItem of items; let i = index\">\n                <ng-container [ngTemplateOutlet]=\"navigationItem\" [ngTemplateOutletContext]=\"{item:childItem}\"></ng-container>\n            </ng-container>\n        </ul>\n    </nav>\n\n</ng-template>\n\n<ng-template #navigationGroup let-item='item'>\n    <ul class=\"{{baseCssClass}}__group\">\n        <ng-container *ngFor=\"let childItem of item.children; let i = index\">\n            <ng-container [ngTemplateOutlet]=\"navigationItem\" [ngTemplateOutletContext]=\"{item:childItem}\"></ng-container>\n        </ng-container>\n    </ul>\n</ng-template>\n\n\n<ng-template #navigationItem let-item='item'>\n    <li [ngClass]=\"getItemCssClass(item)\">\n        <ng-container [ngTemplateOutlet]=\"navigationLink\" [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n        <ng-container *ngIf=\"!!item.children && item.children.length > 0\" [ngTemplateOutlet]=\"navigationGroup\"\n                      [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n    </li>\n</ng-template>\n\n<ng-template #navigationLink let-item='item'>\n    <ng-container *ngIf=\"isItemRouted(item)\" [ngTemplateOutlet]=\"routedLink\" [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n    <ng-container *ngIf=\"!isItemRouted(item)\" [ngTemplateOutlet]=\"staticLink\" [ngTemplateOutletContext]=\"{item:item}\"></ng-container>\n</ng-template>\n\n\n<ng-template #routedLink let-item='item'>\n    <a class=\"{{baseCssClass}}__item-link\"\n       title=\"{{item.title}}\"\n       routerLink=\"{{item.url}}\"\n       routerLinkActive=\"active\"\n       [attr.aria-current]=\"item.active\">\n        {{item.title}}\n    </a>\n</ng-template>\n\n<ng-template #staticLink let-item='item'>\n    <a class=\"{{baseCssClass}}__item-link\"\n       title=\"{{item.title}}\"\n       href=\"{{item.url}}\"\n       [attr.aria-current]=\"item.active\">\n        {{item.title}}\n    </a>\n</ng-template>"
    }),
    __param(0, Inject(NAVIGATION_UTIL_SERVICE)),
    __metadata("design:paramtypes", [Object])
], NavigationV1Component);

let AemAngularCoreWcmComponentsNavigationV1 = class AemAngularCoreWcmComponentsNavigationV1 {
};
AemAngularCoreWcmComponentsNavigationV1 = __decorate([
    NgModule({
        imports: [CommonModule, BrowserModule, RouterModule, AemAngularCoreWcmComponentsCore],
        declarations: [
            NavigationV1Component
        ],
        exports: [
            NavigationV1Component
        ],
        entryComponents: [
            NavigationV1Component,
        ],
    })
], AemAngularCoreWcmComponentsNavigationV1);

/**
 * Generated bundle index. Do not edit.
 */

export { AemAngularCoreWcmComponentsNavigationV1, NavigationV1Component };
//# sourceMappingURL=adobe-aem-core-components-angular-base-layout-navigation-v1.js.map
